@@ -11,7 +11,7 @@
 	## n-1 is here number of lines
 	set ns [info object namespace $Layerobj]	
 	foreach state {color linewidth dash n} {
-	    set ${state}_var [uplevel #0 ${ns}::my varname $state]
+	    set ${state}_var [uplevel #0 [list ${ns}::my varname $state]]
 	}
 	
 	next $Layerobj {*}$args
